@@ -1,19 +1,13 @@
 package MsgPack::RPC::Message;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: a MessagePack-RPC notification
-$MsgPack::RPC::Message::VERSION = '1.0.1';
+$MsgPack::RPC::Message::VERSION = '2.0.0';
 
 use Moose;
-extends 'Beam::Event';
 
-has args => (
-   traits => [ 'Array' ],
-   is => 'ro',
-   default => sub { [] },
-   handles => {
-      all_args => 'elements',
-   },
-);
+sub is_response     { 0 }
+sub is_request      { 0 }
+sub is_notification { 0 }
 
 
 1;
@@ -30,7 +24,7 @@ MsgPack::RPC::Message - a MessagePack-RPC notification
 
 =head1 VERSION
 
-version 1.0.1
+version 2.0.0
 
 =head1 SYNOPSIS
 
@@ -66,7 +60,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Yanick Champoux.
+This software is copyright (c) 2017, 2016, 2015 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
